@@ -36,6 +36,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 
 using namespace std;
 
+
 CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 		numberSpaces ( 0 ),
 		lineNrWidth ( 5 ),
@@ -69,10 +70,12 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 		opt_ordered_list ( false ),
 		opt_fnames_as_anchors ( false ),
 		opt_validate ( false ),
-		opt_inlineCSS ( false ),
-		opt_enclosePreTag ( false ),
-		opt_charStyles ( false ),
-		opt_prettySymbols ( false ),
+		opt_inline_css ( false ),
+		opt_enclose_pre ( false ),
+		opt_char_styles ( false ),
+		opt_pretty_symbols ( false ),
+		opt_delim_CR (false),
+		opt_print_style(false),
 		configFileRead ( false ),
 		anchorPrefix ( "l" ),
 		helpLang ( "en" ),
@@ -84,14 +87,15 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 	enum Optcode
 	{
 		S_OPT_ADDCONFDIR = 256, S_OPT_ENCLOSE_PRE, S_OPT_FORCE_OUTPUT,
-		S_OPT_HELP_LANG, S_OPT_INLINE_CSS, S_OPT_KW_CASE,
+		S_OPT_INLINE_CSS, S_OPT_KW_CASE,
 		S_OPT_MARK_LINES, S_OPT_PRINT_CONFIG, S_OPT_TEST_INPUT,
 		S_OPT_SVG_WIDTH, S_OPT_SVG_HEIGHT, S_OPT_CLASSNAME, S_OPT_RTF_CHAR_STYLES,
 		S_OPT_SKIP_UNKNOWN,
 		S_OPT_COMPAT_DOC, S_OPT_COMPAT_NODOC, S_OPT_COMPAT_TAB, S_OPT_COMPAT_CSS,
 		S_OPT_COMPAT_OUTDIR, S_OPT_COMPAT_FAILSAFE, S_OPT_COMPAT_OUTFORMAT,
 		S_OPT_COMPAT_SRCLANG, S_OPT_COMPAT_LINENUM, S_OPT_COMPAT_LINEREF,
-		S_OPT_CTAGS_FILE, S_OPT_PRETTY_SYMBOLS
+		S_OPT_CTAGS_FILE, S_OPT_PRETTY_SYMBOLS, S_OPT_EOL_DELIM_CR, S_OPT_START_NESTED,
+		S_OPT_PRINT_STYLE
 	};
 
 	const Arg_parser::Option options[] =
@@ -146,12 +150,12 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 		{ 'z', OPT_FILLZEROES,     Arg_parser::no  },
 		{ 'Z', OPT_XML,            Arg_parser::no  },
 		{ 'G', OPT_SVG,            Arg_parser::no  },
+		{ 'Y', OPT_BBCODE,         Arg_parser::no  },
 		{ S_OPT_SVG_WIDTH,    OPT_SVG_WIDTH,    Arg_parser::yes  },
 		{ S_OPT_SVG_HEIGHT,   OPT_SVG_HEIGHT,   Arg_parser::yes  },
 		{ S_OPT_ADDCONFDIR,   OPT_ADDCONFDIR,   Arg_parser::yes },
 		{ S_OPT_ENCLOSE_PRE,  OPT_ENCLOSE_PRE,  Arg_parser::no  },
 		{ S_OPT_FORCE_OUTPUT, OPT_FORCE_OUTPUT, Arg_parser::no  },
-		{ S_OPT_HELP_LANG,    OPT_HELP_LANG,    Arg_parser::yes },
 		{ S_OPT_INLINE_CSS,   OPT_INLINE_CSS,   Arg_parser::no  },
 		{ S_OPT_KW_CASE,      OPT_KW_CASE,      Arg_parser::yes },
 		{ S_OPT_MARK_LINES,   OPT_MARK_LINES,   Arg_parser::yes },
@@ -160,7 +164,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 		{ S_OPT_RTF_CHAR_STYLES, OPT_RTF_CHAR_STYLES, Arg_parser::no  },
 		{ S_OPT_SKIP_UNKNOWN, OPT_SKIP_UNKNOWN, Arg_parser::yes },
 		{ S_OPT_CTAGS_FILE,   OPT_CTAGS_FILE, Arg_parser::maybe },
-
+		{ S_OPT_START_NESTED,   OPT_START_NESTED,   Arg_parser::yes },
 		{ S_OPT_COMPAT_DOC,   OPT_COMPAT_DOC, Arg_parser::no },
 		{ S_OPT_COMPAT_NODOC, OPT_COMPAT_NODOC, Arg_parser::no },
 		{ S_OPT_COMPAT_TAB, OPT_COMPAT_TAB, Arg_parser::yes },
@@ -172,6 +176,8 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 		{ S_OPT_COMPAT_LINENUM, OPT_COMPAT_LINENUM, Arg_parser::maybe },
 		{ S_OPT_COMPAT_LINEREF, OPT_COMPAT_LINEREF, Arg_parser::maybe },
 		{ S_OPT_PRETTY_SYMBOLS, OPT_PRETTY_SYMBOLS, Arg_parser::no },
+		{ S_OPT_EOL_DELIM_CR,   OPT_EOL_DELIM_CR,   Arg_parser::no },
+		{ S_OPT_PRINT_STYLE,    OPT_PRINT_STYLE, Arg_parser::no },
 
 		{ 0,                  0,                Arg_parser::no  }
 	};
@@ -237,7 +243,6 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 				className = arg;
 				break;
 			case 'h':
-			case S_OPT_HELP_LANG:
 				opt_help = true;
 				break;
 			case 'H':
@@ -355,6 +360,9 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 			case 'G':
 				outputType=highlight::SVG;
 				break;
+			case 'Y':
+				outputType=highlight::BBCODE;
+				break;
 			case S_OPT_SVG_WIDTH:
 				svg_width = arg;
 				break;
@@ -365,14 +373,14 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 				additionalConfigDir = validateDirPath ( arg );
 				break;
 			case S_OPT_ENCLOSE_PRE:
-				opt_enclosePreTag=true;
+				opt_enclose_pre=true;
 				break;
 			case S_OPT_FORCE_OUTPUT:
 			case S_OPT_COMPAT_FAILSAFE:
 				opt_force_output = true;
 				break;
 			case S_OPT_INLINE_CSS:
-				opt_inlineCSS=true;
+				opt_inline_css=true;
 				break;
 			case S_OPT_KW_CASE:
 			{
@@ -404,6 +412,8 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 					outputType = highlight::XTERM256;
 				else if ( tmp == "svg" )
 					outputType = highlight::SVG;
+				else if ( tmp == "bbcode" )
+					outputType = highlight::BBCODE;
 				else
 					outputType = highlight::HTML;
 			}
@@ -418,7 +428,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 				opt_validate=true;
 				break;
 			case S_OPT_RTF_CHAR_STYLES:
-				opt_charStyles=true;
+				opt_char_styles=true;
 				break;
 			case S_OPT_SKIP_UNKNOWN:
 				skipArg=arg;
@@ -427,7 +437,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 				ctagsFile = ( arg.empty() ) ? "tags" :arg;
 				break;
 			case S_OPT_PRETTY_SYMBOLS:
-				opt_prettySymbols = true;
+				opt_pretty_symbols = true;
 				break;
 			case S_OPT_COMPAT_DOC:
 				opt_fragment = false;
@@ -437,6 +447,15 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 				opt_attach_line_anchors = true;
 				anchorPrefix = ( arg.empty() ) ? "line":arg;
 				break;
+			case S_OPT_EOL_DELIM_CR:
+				opt_delim_CR = true;
+				break;
+			case S_OPT_START_NESTED:
+				startNestedLang=arg;
+				break;
+			case S_OPT_PRINT_STYLE:
+				opt_print_style = true;
+				break;
 			default:
 				cerr << "highlight: option parsing failed" << endl;
 		}
@@ -615,6 +634,7 @@ string CmdLineOptions::getOutFileSuffix() const
 		case highlight::SVG:   return ".svg";
 		case highlight::ANSI:  return ".ansi";
 		case highlight::XTERM256: return ".xterm";
+		case highlight::BBCODE: return ".bbcode";
 		default:    return ".html";
 	}
 }
@@ -649,7 +669,7 @@ bool CmdLineOptions::disableBabelShorthands() const
 }
 bool CmdLineOptions::prettySymbols() const
 {
-	return opt_prettySymbols;
+	return opt_pretty_symbols;
 }
 bool CmdLineOptions::getFlag ( const string& paramVal )
 {
@@ -664,10 +684,17 @@ bool CmdLineOptions::orderedList() const
 {
 	return opt_ordered_list;
 }
+bool CmdLineOptions::useCRDelimiter() const {
+	return opt_delim_CR;
+}
 const string &CmdLineOptions::getDataDir() const
 {
 	return dataDir;
 }
+bool CmdLineOptions::printOnlyStyle() const {
+	return opt_print_style;
+}
+
 string CmdLineOptions::getIndentScheme() const
 {
 	return StringTools::change_case ( indentScheme );
@@ -730,15 +757,15 @@ bool CmdLineOptions::validateInput() const
 }
 bool CmdLineOptions::inlineCSS() const
 {
-	return opt_inlineCSS;
+	return opt_inline_css;
 }
 bool CmdLineOptions::enclosePreTag() const
 {
-	return opt_enclosePreTag;
+	return opt_enclose_pre;
 }
 bool CmdLineOptions::includeCharStyles() const
 {
-	return opt_charStyles;
+	return opt_char_styles;
 }
 
 const string &CmdLineOptions::getConfigFilePath() const
@@ -838,7 +865,10 @@ const string& CmdLineOptions::getTagsFile() const
 {
 	return ctagsFile;
 }
-
+const string& CmdLineOptions::getStartNestedLang() const 
+{
+	return startNestedLang;
+}
 int CmdLineOptions::getNumberWidth()
 {
 	return lineNrWidth;
@@ -941,7 +971,8 @@ void CmdLineOptions::loadConfigurationFile()
 		opt_fnames_as_anchors=getFlag ( userConfig.getParameter ( OPT_ANCHOR_FN ) );
 		opt_validate=getFlag ( userConfig.getParameter ( OPT_TEST_INPUT ) );
 		opt_fnames_as_anchors=getFlag ( userConfig.getParameter ( OPT_ANCHOR_FN ) );
-		opt_inlineCSS=getFlag ( userConfig.getParameter ( OPT_INLINE_CSS ) );
+		opt_inline_css=getFlag ( userConfig.getParameter ( OPT_INLINE_CSS ) );
+		opt_delim_CR=getFlag ( userConfig.getParameter ( OPT_EOL_DELIM_CR) );
 
 		if ( getFlag ( userConfig.getParameter ( OPT_WRAP ) ) )
 		{
@@ -983,6 +1014,10 @@ void CmdLineOptions::loadConfigurationFile()
 		{
 			outputType=highlight::XTERM256;
 		}
+		else if ( getFlag ( userConfig.getParameter ( OPT_BBCODE) ) )
+		{
+			outputType=highlight::BBCODE;
+		}
 	}
 }
 
