@@ -126,8 +126,17 @@ bool HLCmdLineApp::printInstalledLanguages()
 	{
 		ConfigurationReader lang ( filePaths[i] );
 		desc = lang.getParameter ( "description" );
-		suffix = ( filePaths[i] ).substr ( directory.length() );
-		cout << setw ( 20 ) <<setiosflags ( ios::left ) <<desc<<": "<<suffix.substr ( 1, suffix.length()- wildcard.length() ) << endl;
+		suffix = ( filePaths[i] ).substr ( directory.length() ) ;
+		suffix = suffix.substr ( 1, suffix.length()- wildcard.length() );
+		cout << setw ( 20 ) <<setiosflags ( ios::left ) <<desc<<": "<<suffix;
+		int extCnt=0;
+		for (StringMap::iterator it=extensions.begin();it!=extensions.end();it++) {
+			if (it->second==suffix ) {
+				
+				cout << ((++extCnt==1)?" ( ":" ")<<it->first; 
+			}
+		}
+		cout << ((extCnt)?" )":"")<<endl;
 	}
 	cout <<"\nUse name of the desired language"
 	<< " with the --" OPT_SYNTAX " option.\n" << endl;
@@ -383,12 +392,14 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 	{
 		return printInstalledThemes() ?EXIT_SUCCESS:EXIT_FAILURE;
 	}
+
+	//call before printInstalledLanguages!
+	loadFileTypeConfig ( "filetypes", &extensions, &scriptShebangs );
+
 	if ( options.showLangdefs() )
 	{
 		return printInstalledLanguages() ?EXIT_SUCCESS:EXIT_FAILURE;
-	}
-
-	loadFileTypeConfig ( "filetypes", &extensions, &scriptShebangs );
+	}	
 
 	const  vector <string> inFileList=options.getInputFileNames();
 
@@ -418,6 +429,9 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 
 	generator->setSVGSize ( options.getSVGWidth(),  options.getSVGHeight() );
 
+	if (options.useCRDelimiter())
+		 generator->setEOLDelimiter('\r');
+
 	generator->setValidateInput ( options.validateInput() );
 	generator->setStyleInputPath ( options.getStyleInFilename() );
 	generator->setStyleOutputPath ( options.getStyleOutFilename() );
@@ -434,20 +448,10 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 	generator->setBaseFont ( options.getBaseFont() ) ;
 	generator->setBaseFontSize ( options.getBaseFontSize() ) ;
 	generator->setLineNumberWidth ( options.getNumberWidth() );
-
-	map <int,string> markedLines = options.getMarkLines();
-	if ( !markedLines.empty() )
-	{
-		map<int, string>::iterator it;
-		for ( it=markedLines.begin(); it!=markedLines.end();it++ )
-		{
-			generator->addMarkedLine ( it->first, it->second );
-		}
-	}
+	generator->setStartingNestedLang( options.getStartNestedLang());
 
 	bool styleFileWanted = !options.fragmentOutput() || options.styleOutPathDefined();
 
-
 	if ( !generator->initTheme ( themePath ) )
 	{
 		cerr << "highlight: Could not find style "
@@ -455,17 +459,24 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 		<< ".\n";
 		return EXIT_FAILURE;
 	}
-	/*
-	  if (!options.getIndentScheme().empty()){
-	    string indentSchemePath =
-	              dataDir.getIndentSchemesPath(options.getIndentScheme()+".indent");
-	    if (!generator->initIndentationScheme(indentSchemePath)){
-	        cerr << "highlight: Could not find indentation scheme "
-	             << indentSchemePath
-	             << ".\n";
-	       return EXIT_FAILURE;
-	    }
-	  }*/
+
+	if ( options.printOnlyStyle() )
+	{
+		if (!options.formatSupportsExtStyle()){
+			cerr << "highlight: output format supports no external styles.\n";
+			return EXIT_FAILURE;
+		}
+		bool useStdout =  options.getStyleOutFilename() =="stdout";
+		string cssOutFile=options.getOutDirectory()  + options.getStyleOutFilename();
+		bool success=generator->printExternalStyle ( useStdout?"":cssOutFile );
+		if ( !success )
+		{
+			cerr << "highlight: Could not write " << cssOutFile <<".\n";
+			return EXIT_FAILURE;
+		}
+		return EXIT_SUCCESS;
+	}
+
 	bool formattingEnabled = generator->initIndentationScheme ( options.getIndentScheme() );
 
 	if ( !formattingEnabled && !options.getIndentScheme().empty() )
@@ -500,13 +511,23 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 	dirTest.close();
 #endif
 
+	map <int,string> markedLines = options.getMarkLines();
+	if ( !markedLines.empty() )
+	{
+		map<int, string>::iterator it;
+		for ( it=markedLines.begin(); it!=markedLines.end();it++ )
+		{
+			generator->addMarkedLine ( it->first, it->second );
+		}
+	}
+
 	bool initError=false, IOError=false;
 	unsigned int fileCount=inFileList.size(),
-	                       fileCountWidth=getNumDigits ( fileCount ),
-	                                      i=0,
-	                                        numBadFormatting=0,
-	                                                         numBadInput=0,
-	                                                                     numBadOutput=0;
+	            fileCountWidth=getNumDigits ( fileCount ),
+	            i=0,
+	            numBadFormatting=0,
+	            numBadInput=0,
+	           numBadOutput=0;
 
 	vector<string> badFormattedFiles, badInputFiles, badOutputFiles;
 	string inFileName, outFilePath;
@@ -574,7 +595,6 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 
 		if ( options.enableBatchMode() )
 		{
-
 			outFilePath = outDirectory;
 			outFilePath += inFileName;
 			outFilePath += options.getOutFileSuffix();
@@ -645,18 +665,13 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 	        && styleFileWanted
 	        && options.formatSupportsExtStyle() )
 	{
-		bool useStdout =  options.getStyleOutFilename() =="stdout";
 		string cssOutFile=outDirectory  + options.getStyleOutFilename();
-		bool success=generator->printExternalStyle ( useStdout?"":cssOutFile );
+		bool success=generator->printExternalStyle ( cssOutFile );
 		if ( !success )
 		{
 			cerr << "highlight: Could not write " << cssOutFile <<".\n";
 			IOError = true;
 		}
-		if ( useStdout )
-		{
-			return EXIT_SUCCESS;
-		}
 	}
 
 	if ( i && options.printIndexFile() )
