@@ -2,7 +2,7 @@
                           codegenerator.cpp  -  description
                              -------------------
     begin                : Die Jul 9 2002
-    copyright            : (C) 2002-2008 by Andre Simon
+    copyright            : (C) 2002-2009 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -37,6 +37,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "texgenerator.h"
 #include "xmlgenerator.h"
 #include "svggenerator.h"
+#include "bbcodegenerator.h"
 #include "re/Matcher.h"
 #include "astyle/astyle.h"
 #include "astyle/ASStreamIterator.h"
@@ -53,6 +54,17 @@ namespace highlight
 
 	const unsigned int CodeGenerator::NUMBER_BUILTIN_STATES = 10;
 
+	const string CodeGenerator::STY_NAME_STD="std";
+	const string CodeGenerator::STY_NAME_STR="str";
+	const string CodeGenerator::STY_NAME_NUM="num";
+	const string CodeGenerator::STY_NAME_SLC="slc"; 
+	const string CodeGenerator::STY_NAME_COM="com" ;
+	const string CodeGenerator::STY_NAME_ESC="esc" ;
+	const string CodeGenerator::STY_NAME_DIR="dir" ;
+	const string CodeGenerator::STY_NAME_DST="dstr";
+	const string CodeGenerator::STY_NAME_LIN="line";
+	const string CodeGenerator::STY_NAME_SYM="sym" ;
+
 	CodeGenerator * CodeGenerator::getInstance ( OutputType type )
 	{
 		CodeGenerator* generator=NULL;
@@ -79,6 +91,9 @@ namespace highlight
 			case SVG:
 				generator = new SVGGenerator();
 				break;
+			case BBCODE:
+				generator = new BBCodeGenerator();
+				break;
 #if !defined (QT)
 			case ANSI:
 				generator = new AnsiGenerator();
@@ -93,6 +108,7 @@ namespace highlight
 		return generator;
 	}
 
+
 	CodeGenerator::CodeGenerator ( highlight::OutputType type )
 			:in ( NULL ),
 			out ( NULL ),
@@ -116,114 +132,149 @@ namespace highlight
 			validateInput ( false ),
 			tagsEnabled ( false ),
 			keywordCase ( StringTools::CASE_UNCHANGED ),
+			eolDelimiter ('\n'),
 			outputType ( type )
 	{
 	}
 
+
 	CodeGenerator::~CodeGenerator()
 	{
 		delete formatter;
 	}
 
+
 	bool CodeGenerator::initTheme ( const string& themePath )
 	{
 		this->themePath=themePath;
-		return docStyle.load ( themePath );
+		bool loadOK = docStyle.load ( themePath );
+		//docStyles.insert(docStyles.begin(), docStyle); // main style must be first
+		initOutputTags();
+		return loadOK;
 	}
 
+
 	bool CodeGenerator::hasWhiteBGColour()
 	{
-		StyleColour bgCol = docStyle.getBgColour();
+		//Colour bgCol = docStyles.front().getBgColour();
+		Colour bgCol = docStyle.getBgColour();
 		return bgCol.getRed ( HTML ) == "ff" && bgCol.getGreen ( HTML ) == "ff" && bgCol.getBlue ( HTML ) == "ff";
 	}
 
+
 	const string& CodeGenerator::getStyleName()
 	{
 		return themePath;
 	}
 
+
 	void CodeGenerator::setLineNumberWidth ( int w )
 	{
 		lineNumberWidth=w;
 	}
 
+
 	int CodeGenerator::getLineNumberWidth()
 	{
 		return lineNumberWidth;
 	}
 
+
 	void CodeGenerator::setPrintLineNumbers ( bool flag, unsigned int startCnt )
 	{
 		showLineNumbers=flag;
 		lineNumberOffset = startCnt-1;
 	}
 
+
 	bool CodeGenerator::getPrintLineNumbers()
 	{
 		return showLineNumbers;
 	}
 
+
 	void CodeGenerator::setPrintZeroes ( bool flag )
 	{
 		lineNumberFillZeroes=flag;
 	}
 
+
 	bool CodeGenerator::getPrintZeroes()
 	{
 		return lineNumberFillZeroes;
 	}
 
+
 	void CodeGenerator::setIncludeStyle ( bool flag )
 	{
 		includeStyleDef = flag;
 	}
 
+
 	void CodeGenerator::setStyleInputPath ( const string& path )
 	{
 		styleInputPath = path;
 	}
+
+
 	void CodeGenerator::setStyleOutputPath ( const string& path )
 	{
 		styleOutputPath = path;
 	}
 
+
 	const string&  CodeGenerator::getStyleInputPath()
 	{
 		return styleInputPath;
 	}
+
+
 	const string&  CodeGenerator::getStyleOutputPath()
 	{
 		return styleOutputPath;
 	}
 
+
 	void CodeGenerator::setFragmentCode ( bool flag )
 	{
 		fragmentOutput=flag;
 	}
+
+
 	bool CodeGenerator::getFragmentCode()
 	{
 		return fragmentOutput;
 	}
 
+
 	void CodeGenerator::setValidateInput ( bool flag )
 	{
 		validateInput=flag;
 	}
+
+
 	bool CodeGenerator::getValidateInput()
 	{
 		return validateInput;
 	}
 
+
 	void CodeGenerator::setBaseFont ( const string& s )
 	{
 		baseFont = s;
 	}
 
+
 	void CodeGenerator::setBaseFontSize ( const string& s )
 	{
 		baseFontSize = s ;
 	}
 
+	void CodeGenerator::setStartingNestedLang(const string &langName) {
+		embedLangStart = langName;
+	}
+
+
 	const string CodeGenerator::getBaseFont() const
 	{
 		if ( !baseFont.empty() ) return baseFont;
@@ -240,10 +291,12 @@ namespace highlight
 		}
 	}
 
-	const string& CodeGenerator::getBaseFontSize()
+
+	const string CodeGenerator::getBaseFontSize()
 	{
 		if ( baseFontSize.empty() && outputType != LATEX && outputType != TEX )
 		{
+			//return docStyles.front().getFontSize();
 			return docStyle.getFontSize();
 		}
 		else
@@ -252,36 +305,43 @@ namespace highlight
 		}
 	}
 
+
 	void CodeGenerator::setTitle ( const string & title )
 	{
 		if ( !title.empty() ) docTitle= title;
 	}
 
+
 	string CodeGenerator::getTitle()
 	{
 		return docTitle;
 	}
 
+
 	void CodeGenerator::setEncoding ( const string& encodingName )
 	{
 		encoding = encodingName;
 	}
 
+
 	bool CodeGenerator::formattingDisabled()
 	{
 		return !formattingEnabled;
 	}
 
+
 	void CodeGenerator::setMaxInputLineCnt ( unsigned int cnt )
 	{
 		maxLineCnt = cnt;
 	}
 
+
 	bool CodeGenerator::formattingIsPossible()
 	{
 		return formattingPossible;
 	}
 
+
 	void CodeGenerator::setPreformatting ( WrapMode lineWrappingStyle,
 	                                       unsigned int lineLength,
 	                                       int numberSpaces )
@@ -299,21 +359,30 @@ namespace highlight
 		}
 	}
 
+
 	void CodeGenerator::setKeyWordCase ( StringTools::KeywordCase keyCase )
 	{
 		keywordCase = keyCase;
 	}
 
+
 	void CodeGenerator::addMarkedLine ( int lineNo, string& helpTxt )
 	{
 		markLines[lineNo] = helpTxt;
 	}
 
+
 	const LanguageDefinition &CodeGenerator::getLanguage()
 	{
 		return langInfo;
 	}
 
+
+	void CodeGenerator::setEOLDelimiter(char delim){
+		eolDelimiter = delim;
+	}
+
+
 	void CodeGenerator::reset()
 	{
 		lineIndex = 0;
@@ -322,8 +391,11 @@ namespace highlight
 		preFormatter.reset();
 		inFile.clear();
 		outFile.clear();
+		hostLangDefPath.clear();
+		embedLangDefPath.clear();
 	}
 
+
 	/** sucht vorwaerts ab Position searchPos Ziffer in s und liefert Integerwert
 	der gefundenen Zahl zurueck.
 	Im SymbolString stehen die den einzelnen Symbolen zugeordneten Konstanten
@@ -339,11 +411,13 @@ namespace highlight
 		return ( State ) result;
 	}
 
+
 	unsigned int CodeGenerator::getLineNumber()
 	{
 		return lineNumber;
 	}
 
+
 	bool CodeGenerator::readNewLine ( string &newLine )
 	{
 
@@ -360,18 +434,13 @@ namespace highlight
 		// reformatting not enabled
 		else
 		{
-#ifdef __APPLE__
-			eof = ! getline ( *in, newLine, '\r' ); // MacOS
-#else
-			eof = ! getline ( *in, newLine );        // other OS
-#endif
+			eof = ! getline ( *in, newLine, eolDelimiter );
 		}
 
 		return eof || ( lineNumber == maxLineCnt );
 	}
 
 
-
 	void CodeGenerator::matchRegex ( const string &line )
 	{
 
@@ -379,29 +448,35 @@ namespace highlight
 		int matchBegin=0;
 		int matchLen=0;
 		int groupID=0;
+
 		// cycle through all regex, save the start and ending indices to report them later
 		for ( unsigned int i=0; i<langInfo.getRegexElements().size(); i++ )
 		{
 			RegexElement *regexElem = langInfo.getRegexElements() [i];
 			auto_ptr<Matcher> matcher ( regexElem->rePattern->createMatcher ( line ) );
+
 			while ( matcher->findNextMatch() )
 			{
 				groupID = ( regexElem->capturingGroup<0 ) ? matcher->getGroupNum()-1 : regexElem->capturingGroup;
 				matchBegin =  matcher->getStartingIndex ( groupID );
 				if ( matchBegin<0 ) continue;
+
 				matchLen = matcher->getEndingIndex ( groupID ) - matchBegin;
 				/*
 				            std::cerr << "\nmatchBegin="<<1+ matchBegin
 				                      << " matchLen old" << ( matcher->getGroup(matcher->getGroupNum()-1).size())
 				                      << " matchLen new" << matchLen<<" group: "<<(matcher->getGroup(matcher->getGroupNum()-1))
-				                      << " group id= "<<regexElem->groupID<<"\n";
+				                      << " group id= "<<regexElem->capturingGroup
+							<< " lang= "<<regexElem->langName<<"\n";
+					    cerr<<"match: "<<(matcher->getGroup(matcher->getGroupNum()-1))<<" id: "<<regexElem->open<<endl;
 				*/
 				regexGroups.insert (
-				    make_pair ( matchBegin+1, ReGroup ( regexElem->open, matchLen, regexElem->kwClass ) ) );
+				    make_pair ( matchBegin+1, ReGroup ( regexElem->open, matchLen, regexElem->kwClass, regexElem->langName ) ) );
 			}
 		}
 	}
 
+
 	unsigned char CodeGenerator::getInputChar()
 	{
 		bool eol = lineIndex == line.length();
@@ -433,6 +508,7 @@ namespace highlight
 		return line[lineIndex++];
 	}
 
+
 	State CodeGenerator::getCurrentState ()
 	{
 
@@ -457,7 +533,6 @@ namespace highlight
 			return _EOF;   // End of file
 		}
 
-//  if (iswspace(c)) {
 		if ( c==' ' || c=='\t' )
 		{
 			token= c;
@@ -476,8 +551,11 @@ namespace highlight
 			{
 				token = line.substr ( lineIndex-1, regexGroups[lineIndex].length );
 				unsigned int oldIndex= lineIndex;
-				if ( regexGroups[oldIndex].length>1 ) lineIndex+= regexGroups[lineIndex].length-1;
+				if ( regexGroups[oldIndex].length>1 ) lineIndex+= regexGroups[oldIndex].length-1;
 
+				if ( regexGroups[oldIndex].state==EMBEDDED_CODE_BEGIN) {
+					embedLangDefPath = langInfo.getNewPath(regexGroups[oldIndex].name);
+				}
 				if ( regexGroups[oldIndex].state==IDENTIFIER_BEGIN || regexGroups[oldIndex].state==KEYWORD )
 				{
 					string reservedWord= ( langInfo.isIgnoreCase() ) ? StringTools::change_case ( token ) :token;
@@ -528,7 +606,8 @@ namespace highlight
 		return STANDARD;
 	}
 
-//it is faster to pass ostream reference
+
+	//it is faster to pass ostream reference
 	void CodeGenerator::maskString ( ostream& ss, const string & s )
 	{
 		for ( unsigned int i=0;i< s.length();i++ )
@@ -537,6 +616,7 @@ namespace highlight
 		}
 	}
 
+
 	void CodeGenerator::printMaskedToken ( bool addMetaInfo, bool flushWhiteSpace,
 	                                       StringTools::KeywordCase tcase )
 	{
@@ -556,17 +636,21 @@ namespace highlight
 		token.clear();
 	}
 
+
 	bool CodeGenerator::styleFound()
 	{
 		return docStyle.found();
+		//return docStyles.front().found();
 	}
 
+
 	bool CodeGenerator::printIndexFile ( const vector<string> &fileList,
 	                                     const string &outPath )
 	{
 		return true;
 	}
 
+
 	bool CodeGenerator::initIndentationScheme ( const string &indentScheme )
 	{
 
@@ -619,12 +703,13 @@ namespace highlight
 		return formattingEnabled=true;
 	}
 
+
 	LoadResult CodeGenerator::loadLanguage ( const string& langDefPath )
 	{
 		bool reloadNecessary= langInfo.needsReload ( langDefPath );
 		if ( reloadNecessary )
 		{
-
+			//cerr<<"LOADING"<<langDefPath<<endl;
 			if ( !langInfo.load ( langDefPath ) )
 			{
 				return langInfo.getFailedRegex().size() ? LOAD_FAILED_REGEX : LOAD_FAILED;
@@ -632,24 +717,24 @@ namespace highlight
 
 			formattingPossible=langInfo.enableReformatting();
 
-			if ( styleTagOpen.size() >NUMBER_BUILTIN_STATES )
+			if ( openTags.size() >NUMBER_BUILTIN_STATES )
 			{
 				// remove dynamic keyword tag delimiters of the old language definition
 				vector<string>::iterator keyStyleOpenBegin =
-				    styleTagOpen.begin() + NUMBER_BUILTIN_STATES;
+				    openTags.begin() + NUMBER_BUILTIN_STATES;
 				vector<string>::iterator keyStyleCloseBegin =
-				    styleTagClose.begin() + NUMBER_BUILTIN_STATES;
-				styleTagOpen.erase ( keyStyleOpenBegin, styleTagOpen.end() );
-				styleTagClose.erase ( keyStyleCloseBegin, styleTagClose.end() );
+				    closeTags.begin() + NUMBER_BUILTIN_STATES;
+				openTags.erase ( keyStyleOpenBegin, openTags.end() );
+				closeTags.erase ( keyStyleCloseBegin, closeTags.end() );
 			}
 			// add new keyword tag delimiters
 			for ( unsigned int i=0;i< langInfo.getKeywordClasses().size(); i++ )
 			{
-				styleTagOpen.push_back ( getMatchingOpenTag ( i ) );
-				styleTagClose.push_back ( getMatchingCloseTag ( i ) );
+				openTags.push_back ( getKeywordOpenTag ( i ) );
+				closeTags.push_back ( getKeywordCloseTag ( i ) );
 			}
 		}
-		return ( reloadNecessary ) ? LOAD_NEW : LOAD_NONE;
+		return ( reloadNecessary) ? LOAD_NEW : LOAD_NONE;
 	}
 
 
@@ -660,6 +745,7 @@ namespace highlight
 		return tagsEnabled;
 	}
 
+
 	bool CodeGenerator::validateInputStream()
 	{
 		if ( !in ) return false;
@@ -718,7 +804,6 @@ namespace highlight
 	}
 
 
-
 	ParseError CodeGenerator::generateFile ( const string &inFileName,
 	        const string &outFileName )
 	{
@@ -782,6 +867,7 @@ namespace highlight
 		return error;
 	}
 
+
 	string CodeGenerator::generateString ( const string &input )
 	{
 
@@ -873,6 +959,7 @@ namespace highlight
 		return result;
 	}
 
+
 	unsigned int CodeGenerator::getStyleID ( State s, unsigned int kwClassID )
 	{
 		if ( s==KEYWORD && kwClassID )
@@ -882,32 +969,46 @@ namespace highlight
 		return ( unsigned int ) s ;
 	}
 
+
 	void CodeGenerator::openTag ( State s )
 	{
-		*out << styleTagOpen[ ( unsigned int ) s];
+		*out << openTags[ ( unsigned int ) s];
 		currentState=s;
 	}
 
+
 	void CodeGenerator::closeTag ( State s )
 	{
-		*out << styleTagClose[ ( unsigned int ) s];
+		*out << closeTags[ ( unsigned int ) s];
 		flushWs();
 		currentState=_UNKNOWN;
 	}
 
+
 	void CodeGenerator::openKWTag ( unsigned int kwClassID )
 	{
-		*out << styleTagOpen[getStyleID ( KEYWORD, kwClassID ) ];
+		*out << openTags.at(getStyleID ( KEYWORD, kwClassID ) );
 		currentState=KEYWORD;
 	}
 
+
 	void CodeGenerator::closeKWTag ( unsigned int kwClassID )
 	{
-		*out << styleTagClose[getStyleID ( KEYWORD, kwClassID ) ];
+		*out << closeTags.at(getStyleID ( KEYWORD, kwClassID ) );
 		flushWs();
 		currentState=_UNKNOWN;
 	}
 
+	void CodeGenerator::loadEmbeddedLang(const string&embedLangDefPath){
+			//save path of host language
+			if (hostLangDefPath.empty()) {
+				hostLangDefPath =langInfo.getCurrentPath();
+			}
+			//load syntax of embedded langage
+			loadLanguage(embedLangDefPath);
+			//pass end delimiter regex to syntax description
+			langInfo.restoreLangEndDelim(embedLangDefPath);
+	}
 
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -932,6 +1033,8 @@ namespace highlight
 			return;
 		}
 
+		if (!embedLangStart.empty()) loadEmbeddedLang(langInfo.getNewPath(embedLangStart));
+
 		State state=STANDARD;
 
 		openTag ( STANDARD );
@@ -990,6 +1093,12 @@ namespace highlight
 					eof=processSymbolState();
 					openTag ( STANDARD );
 					break;
+				case EMBEDDED_CODE_BEGIN:
+				case EMBEDDED_CODE_END:
+					closeTag ( STANDARD );
+					eof=processSyntaxChangeState(state);
+					openTag ( STANDARD );
+					break;
 				case _EOL:
 					insertLineNumber ( !firstLine );
 					firstLine=false;
@@ -1011,6 +1120,55 @@ namespace highlight
 		*out << flush;
 	}
 
+	bool CodeGenerator::processSyntaxChangeState(State myState)
+	{
+		State newState=STANDARD;
+		bool eof=false,
+		         exitState=false;
+		openTag ( KEYWORD );
+		do
+		{
+			if (myState==EMBEDDED_CODE_BEGIN) {
+				loadEmbeddedLang(embedLangDefPath);
+				
+				//test current line again to match tokens of the embedded language
+				matchRegex(line);
+				
+			}
+			else if (myState==EMBEDDED_CODE_END) {
+				// load host language syntax
+				loadLanguage(hostLangDefPath);
+				//test current line again to match tokens of the host language
+				matchRegex(line);
+				
+			}
+
+			printMaskedToken ( false, newState!=_WS );
+			newState= getCurrentState();
+			switch ( newState )
+			{
+				case _WS:
+					processWsState();
+					break;
+				case _EOL:
+					insertLineNumber();
+					exitState=true;
+					break;
+				case _EOF:
+					eof = true;
+					break;
+				default:
+					exitState=true;
+					break;
+			}
+		}
+		while ( ( !exitState ) && ( !eof ) );
+
+		closeTag ( KEYWORD );
+		return eof;
+	}
+
+
 	bool CodeGenerator::processKeywordState ( State myState )
 	{
 		State newState=STANDARD;
@@ -1052,6 +1210,7 @@ namespace highlight
 		return eof;
 	}
 
+
 	bool CodeGenerator::processNumberState()
 	{
 		State newState=STANDARD;
@@ -1085,6 +1244,7 @@ namespace highlight
 		return eof;
 	}
 
+
 	bool CodeGenerator::processMultiLineCommentState()
 	{
 		int commentCount=1;
@@ -1103,9 +1263,9 @@ namespace highlight
 					processWsState();
 					break;
 				case _EOL:
-					wsBuffer += styleTagClose[ML_COMMENT];
+					wsBuffer += closeTags[ML_COMMENT];
 					insertLineNumber();
-					wsBuffer += styleTagOpen[ML_COMMENT];
+					wsBuffer += openTags[ML_COMMENT];
 					break;
 				case _EOF:
 					eof = true;
@@ -1114,10 +1274,6 @@ namespace highlight
 					if ( langInfo.allowNestedMLComments() )
 					{
 						++commentCount;
-						// SmallTalk-Fix: if multiline comment delims are equal,
-						// end comment when the same delimiter is read again and
-						// nested comments are not allowed
-						//break;
 					}
 					// if delimiters are equal, close the comment by continueing to
 					// ML_COMMENT_END section
@@ -1142,6 +1298,7 @@ namespace highlight
 		return eof;
 	}
 
+
 	bool CodeGenerator::processSingleLineCommentState()
 	{
 
@@ -1174,9 +1331,9 @@ namespace highlight
 					{
 						exitState=true;
 					}
-					if ( !exitState ) wsBuffer += styleTagClose[SL_COMMENT];
+					if ( !exitState ) wsBuffer += closeTags[SL_COMMENT];
 					insertLineNumber();
-					if ( !exitState ) wsBuffer += styleTagOpen[SL_COMMENT];
+					if ( !exitState ) wsBuffer += openTags[SL_COMMENT];
 
 					break;
 				case _EOF:
@@ -1192,6 +1349,7 @@ namespace highlight
 		return eof;
 	}
 
+
 	bool CodeGenerator::processDirectiveState()
 	{
 		State  newState=STANDARD;
@@ -1221,9 +1379,9 @@ namespace highlight
 					{
 						exitState= ( terminatingChar!=langInfo.getContinuationChar() );
 					}
-					if ( !exitState ) wsBuffer += styleTagClose[DIRECTIVE];
+					if ( !exitState ) wsBuffer += closeTags[DIRECTIVE];
 					insertLineNumber();
-					if ( !exitState ) wsBuffer += styleTagOpen[DIRECTIVE];
+					if ( !exitState ) wsBuffer += openTags[DIRECTIVE];
 					break;
 				case ML_COMMENT:
 					closeTag ( DIRECTIVE );
@@ -1254,6 +1412,7 @@ namespace highlight
 		return eof;
 	}
 
+
 	bool CodeGenerator::processStringState ( State oldState )
 	{
 		State newState=STANDARD;
@@ -1285,9 +1444,9 @@ namespace highlight
 					processWsState();
 					break;
 				case _EOL:
-					wsBuffer += styleTagClose[myState];
+					wsBuffer += closeTags[myState];
 					insertLineNumber();
-					wsBuffer += styleTagOpen[myState];
+					wsBuffer += openTags[myState];
 					break;
 				case STRING_END:
 					exitState= true;
@@ -1322,6 +1481,7 @@ namespace highlight
 		return eof;
 	}
 
+
 	bool CodeGenerator::processSymbolState()
 	{
 
@@ -1357,6 +1517,7 @@ namespace highlight
 		return eof;
 	}
 
+
 	bool CodeGenerator::processEscapeCharState()
 	{
 		State newState=STANDARD;
@@ -1389,6 +1550,7 @@ namespace highlight
 		return eof;
 	}
 
+
 	void CodeGenerator::processWsState()
 	{
 		if ( !maskWs )
@@ -1413,7 +1575,7 @@ namespace highlight
 			unsigned int styleID=getStyleID ( currentState, currentKeywordClass );
 			if ( excludeWs && styleID!=_UNKNOWN )
 			{
-				*out << styleTagClose[styleID];
+				*out << closeTags[styleID];
 			}
 			*out << maskWsBegin;
 			for ( int i=0; i<cntWs; i++ )
@@ -1423,7 +1585,7 @@ namespace highlight
 			*out << maskWsEnd;
 			if ( excludeWs && styleID!=_UNKNOWN )
 			{
-				*out << styleTagOpen[styleID];
+				*out << openTags[styleID];
 			}
 		}
 		else
@@ -1433,17 +1595,20 @@ namespace highlight
 		token.clear();
 	}
 
+
 	void CodeGenerator::flushWs()
 	{
 		*out<<wsBuffer;
 		wsBuffer.clear();
 	}
 
+
 	string CodeGenerator::getNewLine()
 	{
 		return newLineTag;
 	}
 
+
 	void CodeGenerator::insertLineNumber ( bool insertNewLine )
 	{
 
@@ -1462,23 +1627,25 @@ namespace highlight
 			}
 			os <<setw ( getLineNumberWidth() ) << right << lineNumber+lineNumberOffset;
 
-			numberPrefix << styleTagOpen[LINENUMBER];
+			numberPrefix << openTags[LINENUMBER];
 			maskString ( numberPrefix, os.str() );
 			numberPrefix << spacer
-			<< styleTagClose[LINENUMBER];
+			<< closeTags[LINENUMBER];
 
 			wsBuffer += numberPrefix.str();
 		}
 	}
 
+
 	unsigned int CodeGenerator::getLineIndex()
 	{
 		return lineIndex;
 	}
 
+
 	bool CodeGenerator::printExternalStyle ( const string &outFile )
 	{
-		if ( !includeStyleDef && langInfo.getSyntaxHighlight() )
+		if ( !includeStyleDef && langInfo.highlightingEnabled() )
 		{
 			ostream *cssOutFile = ( outFile.empty() ? &cout :new ofstream ( outFile.c_str() ) );
 			if ( !cssOutFile->fail() )
@@ -1503,6 +1670,7 @@ namespace highlight
 		return true;
 	}
 
+
 	string CodeGenerator::readUserStyleDef()
 	{
 		ostringstream ostr;
@@ -1511,9 +1679,9 @@ namespace highlight
 			ifstream userStyleDef ( styleInputPath.c_str() );
 			if ( userStyleDef )
 			{
-				ostr << "\n" << styleCommentOpen
-				<< " Content of " << styleInputPath
-				<< ": " <<styleCommentClose << "\n";
+				ostr 	<< "\n" << styleCommentOpen
+					<< " Content of " << styleInputPath
+					<< ": " <<styleCommentClose << "\n";
 				string line;
 				while ( getline ( userStyleDef, line ) )
 				{
@@ -1523,9 +1691,9 @@ namespace highlight
 			}
 			else
 			{
-				ostr << styleCommentOpen
-				<< " ERROR: Could not include " << styleInputPath
-				<< "." << styleCommentClose << "\n";
+				ostr 	<< styleCommentOpen
+					<< " ERROR: Could not include " << styleInputPath
+					<< "." << styleCommentClose << "\n";
 			}
 		}
 		return ostr.str();
@@ -1573,13 +1741,7 @@ namespace highlight
 				else if ( replaceVar=="$theme"||replaceVar=="$style" )
 				{
 					res+= getStyleName();
-				}/*
-          else if (replaceVar=="$style-infile") {
-             res+= getStyleInputPath();
-          }
-          else if (replaceVar=="$style-outfile") {
-             res+= getStyleOutputPath();
-          }*/
+				}
 				else if ( replaceVar=="$font-face" )
 				{
 					res+= getBaseFont();
