@@ -45,8 +45,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 
 namespace highlight
 {
-
-
 	/** \brief Regular Expession Information
 
 	    This class associates a processing state with a keyword class and the length of the matched token.
@@ -58,13 +56,13 @@ namespace highlight
 		public:
 
 			/// Constructor
-			ReGroup() : length ( 0 ), state ( STANDARD ), kwClass ( 0 )
+			ReGroup() : length ( 0 ), state ( STANDARD ), kwClass ( 0 ), name()
 			{
 			}
 
 			/// Constructor
-			ReGroup ( State s, unsigned int l , unsigned int c ) :
-					length ( l ), state ( s ), kwClass ( c )
+			ReGroup ( State s, unsigned int l , unsigned int c, const string&n ) :
+					length ( l ), state ( s ), kwClass ( c ), name(n)
 			{
 			}
 
@@ -74,6 +72,7 @@ namespace highlight
 				length = other.length;
 				state = other.state;
 				kwClass = other.kwClass;
+				name=other.name;
 			}
 
 			/// Operator overloading
@@ -82,6 +81,7 @@ namespace highlight
 				length = other.length;
 				state = other.state;
 				kwClass = other.kwClass;
+				name=other.name;
 				return *this;
 			}
 
@@ -92,6 +92,7 @@ namespace highlight
 			unsigned int length;    ///< length of the token
 			State state;            ///< state of the matched token (keyword, string, etc)
 			unsigned int kwClass;   ///< keyword class if state is keyword
+			string name;           ///< language name needed to handle embedded languages
 	};
 
 
@@ -103,7 +104,8 @@ namespace highlight
 	    The colour information is stored in a DocumentStyle instance.<br>
 	    Codegenerator is a singleton class.<br>
 	    Use getInstance for a singleton class instance. Then call the init* methods
-	    and loadLanguage to initialize the parser. Call generate* methods to get results.
+	    and loadLanguage to initialize the parser. Init methods have to be called first.
+	    Call generate* methods to get results.
 
 	* @author Andre Simon
 	*/
@@ -135,7 +137,7 @@ namespace highlight
 			 \param themePath Path of style description file
 			 \return true if successfull
 			*/
-			virtual bool initTheme ( const string& themePath );
+			bool initTheme ( const string& themePath );
 
 			/** initialize source code indentation and reformatting scheme;
 			    needs to be called before using a generate* method
@@ -282,7 +284,7 @@ namespace highlight
 			void setBaseFontSize ( const string& s );
 
 			/** \return base font size*/
-			const string& getBaseFontSize();
+			const string getBaseFontSize();
 
 			/** tell parser the include style definition in output
 			    \param flag true if style should be included
@@ -329,6 +331,16 @@ namespace highlight
 			    \param helpTxt additional help text */
 			void addMarkedLine ( int lineNo, string &helpTxt );
 
+			/** \param delim End of line delimiter (default: NL)
+			*/
+			void setEOLDelimiter(char delim);
+
+			/** Define the name of a nested langage which is located at the beginning of input.
+			    The opening embedded delimiter is missing, but the closing delimiter must exist.
+				\param langName name of nested language
+			*/
+			void setStartingNestedLang(const string &langName);
+
 
 			/** set HTML output anchor flag
 			 */
@@ -383,6 +395,17 @@ namespace highlight
 
 			static const unsigned int NUMBER_BUILTIN_STATES;  ///< number of token states (without keyword group IDs)
 
+			static const string STY_NAME_STD;
+			static const string STY_NAME_STR;
+			static const string STY_NAME_NUM;
+			static const string STY_NAME_SLC;
+			static const string STY_NAME_COM;
+			static const string STY_NAME_ESC;
+			static const string STY_NAME_DIR;
+			static const string STY_NAME_DST;
+			static const string STY_NAME_LIN;
+			static const string STY_NAME_SYM;
+
 			/** \param type Output type */
 			CodeGenerator ( highlight::OutputType type );
 			CodeGenerator() {};
@@ -404,8 +427,8 @@ namespace highlight
 			  \return line number  */
 			unsigned int getLineNumber();
 
-			vector <string> styleTagOpen,   ///< list of format delimiters (open new format descriptions)
-			styleTagClose;   ///< list of format delimiters (close format descriptions)
+			vector <string> openTags,   ///< list of format delimiters (open new format descriptions)
+			closeTags;   ///< list of format delimiters (close format descriptions)
 
 			/** Description of document colour style*/
 			DocumentStyle docStyle;
@@ -434,6 +457,9 @@ namespace highlight
 			string styleCommentOpen,  ///< open comment delimiter
 			styleCommentClose; ///< close comment delimiter
 
+			string embedBlockOpen,  ///< open block delimiter to highlight embedded code
+			embedBlockClose; ///< close block delimiter
+
 			/** Encoding name */
 			string encoding;
 
@@ -540,11 +566,16 @@ namespace highlight
 			*/
 			virtual string getHeader() = 0;
 
-			/** return matching open tags of the given state */
-			virtual string getMatchingOpenTag ( unsigned int ) = 0;
+			/** initialize tags in specific format according to colouring information provided in DucumentStyle */
+			virtual void initOutputTags() = 0;
 
-			/** return matching close tags of the given state */
-			virtual string getMatchingCloseTag ( unsigned int ) = 0;
+			/** 	\param keyword group id
+				\return  open tag  */
+			virtual string getKeywordOpenTag ( unsigned int ) = 0;
+
+			/** 	\param keyword group id
+				\return  close tag  */
+			virtual string getKeywordCloseTag ( unsigned int ) = 0;
 
 			/** return open tag to include ctags meta information
 			   \param info tag information of current token
@@ -563,13 +594,30 @@ namespace highlight
 			/** close opened tag, clear current state */
 			void closeTag ( State s );
 
-			void closeTag ( unsigned int styleID );
+			/** close Keyword tag of corresponding style ID */
+			void closeKWTag ( unsigned int styleID );
 
-			void openTag ( unsigned int styleID );
+			/** open Keyword tag of corresponding style ID */
+			void openKWTag ( unsigned int styleID );
+
+			
+
+			/*void closeTag ( unsigned int styleID );
+
+			void openTag ( unsigned int styleID );*/
 
 			/// path to style definition file
 			string themePath;
 
+			/// path to host language definition
+			string hostLangDefPath;
+
+			/// path to embedded language definition
+			string embedLangDefPath;
+
+			/// name of nested language which starts the input (ie opening delim missing, but closing delim exists)
+			string embedLangStart;
+
 			/// contains current position in line
 			unsigned int lineIndex;
 
@@ -606,6 +654,9 @@ namespace highlight
 			string styleInputPath,   ///< style input file path
 			styleOutputPath;  ///< style output file path
 
+			/** end-of-line delimiter*/
+			char eolDelimiter;
+
 			/** Resets parser to origin state, call this after every file conversion */
 			void reset();
 
@@ -615,6 +666,7 @@ namespace highlight
 			/** return next character from in stream */
 			unsigned char getInputChar();
 
+			/** output file type */
 			OutputType outputType;
 
 			/** return new state */
@@ -631,6 +683,7 @@ namespace highlight
 			bool processTagState();                   ///< process tags
 			bool processSymbolState();                ///< process symbols
 			void processWsState();                    ///< process whitespace
+			bool processSyntaxChangeState(State myState ); ///< process syntax change of embedded languages
 
 			/** print escaped token and clears it
 			   \param addMetaInfo set true if token may have meta information
@@ -640,12 +693,6 @@ namespace highlight
 			void printMaskedToken ( bool addMetaInfo = false, bool flushWhiteSpace = true,
 			                        StringTools::KeywordCase tcase = StringTools::CASE_UNCHANGED );
 
-			/** close Keyword tag of corresponding style ID */
-			void closeKWTag ( unsigned int styleID );
-
-			/** open Keyword tag of corresponding style ID */
-			void openKWTag ( unsigned int styleID );
-
 			/** look for special commands in comments
 			    \return true if command was found
 			*/
@@ -661,6 +708,8 @@ namespace highlight
 			/** \return true if input is no binary stream */
 			bool validateInputStream();
 
+			void loadEmbeddedLang(const string&embedLangDefPath);
+
 	};
 
 }
