@@ -474,6 +474,7 @@ void MainWindow::on_action_About_Highlight_triggered()
      case 4: return highlight::RTF;
      case 5: return highlight::SVG;
      case 6: return highlight::XML;
+     case 7: return highlight::BBCODE;
     }
     return highlight::HTML;
 }
@@ -487,6 +488,7 @@ void MainWindow::on_action_About_Highlight_triggered()
     case 4: return ".rtf";
     case 5: return ".svg";
     case 6: return ".xml";
+    case 7: return ".bbcode";
   }
   return ".html";
 }
@@ -597,16 +599,6 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
     }
 
    if (ui->cbReformat->isChecked()){
-       /*
-#ifdef DATA_DIR
-           QString reformatPath = QString("%1/indentSchemes/%2.indent").arg(
-                   DATA_DIR).arg(ui->comboReformat->currentText());
-#else
-           QString reformatPath = QString("%1/indentSchemes/%2.indent").arg(
-                   QDir::currentPath()).arg(ui->comboReformat->currentText());
-#endif
-                   */
-           //generator->initIndentationScheme(reformatPath.toStdString());
        generator->initIndentationScheme(ui->comboReformat->currentText().toLower().toStdString());
 
     }
@@ -874,8 +866,9 @@ void MainWindow::on_pbPaste2Clipboard_clicked(){
 
      switch (ui->comboFormat->currentIndex()) {
     case 0:
-    case 1:  ui->stackedSpecificOptions->setCurrentIndex(0);
-            break;
+    case 1:
+         ui->stackedSpecificOptions->setCurrentIndex(0);
+         break;
     case 2:
          ui->stackedSpecificOptions->setCurrentIndex(1);
          break;
